package com.jiuqi.grid.output;

import com.jiuqi.util.JqLib;
import java.text.DecimalFormat;

public class CurrencyBoxHTMLGenerator
{
    private int decimal;
    private int precision;
    private int type;
    private String value;
    private String moneySign;
    
    public CurrencyBoxHTMLGenerator(final int decimal, final int precision, final String value, final int type, final String moneySign) {
        this.decimal = decimal;
        this.precision = precision;
        this.type = type;
        this.value = value;
        this.moneySign = moneySign;
    }
    
    public String generate() {
        this.decimal = this.getDecimal(this.decimal);
        this.precision = this.getPrecision(this.decimal, this.precision);
        if (this.value.equals("|")) {
            return this.getTitleHTML(this.decimal, this.precision);
        }
        if (this.moneySign == null) {
            this.moneySign = "";
        }
        return this.getDataHTML(this.decimal, this.precision, this.value, this.type, this.moneySign);
    }
    
    private int getDecimal(final int dec) {
        if (dec == 0) {
            return 0;
        }
        return 2;
    }
    
    private int getPrecision(final int dec, final int pre) {
        if (dec == 0) {
            if (pre >= 2 && pre <= 13) {
                return pre;
            }
            return 13;
        }
        else {
            if (pre >= 4 && pre <= 15) {
                return pre;
            }
            return 15;
        }
    }
    
    private char formatNumber(final char c, final int type) {
        if (type == 0) {
            return c;
        }
        if (type == 1) {
            switch (c) {
                case '1': {
                    return '一';
                }
                case '2': {
                    return '二';
                }
                case '3': {
                    return '三';
                }
                case '4': {
                    return '四';
                }
                case '5': {
                    return '五';
                }
                case '6': {
                    return '六';
                }
                case '7': {
                    return '七';
                }
                case '8': {
                    return '八';
                }
                case '9': {
                    return '九';
                }
                case '0': {
                    return 'O';
                }
                case '-': {
                    return '负';
                }
                default: {
                    return '错';
                }
            }
        }
        else {
            switch (c) {
                case '1': {
                    return '壹';
                }
                case '2': {
                    return '贰';
                }
                case '3': {
                    return '叁';
                }
                case '4': {
                    return '肆';
                }
                case '5': {
                    return '伍';
                }
                case '6': {
                    return '陆';
                }
                case '7': {
                    return '柒';
                }
                case '8': {
                    return '捌';
                }
                case '9': {
                    return '玖';
                }
                case '0': {
                    return '零';
                }
                case '-': {
                    return '负';
                }
                default: {
                    return '错';
                }
            }
        }
    }
    
    private boolean isFlagNumber(final int num, final boolean bool) {
        switch (num) {
            case 1: {
                return bool;
            }
            case 4:
            case 7:
            case 10:
            case 13: {
                return true;
            }
            default: {
                return false;
            }
        }
    }
    
    private String getDataHTML(final int dec, final int pre, final String val, final int ty, final String mSigh) {
        final DecimalFormat doublefmt = new DecimalFormat();
        final StringBuffer dataHTML = new StringBuffer();
        int length = 0;
        double percent = 100.0 / pre;
        final int b = (int)Math.round(percent * 100.0);
        percent = b / 100.0;
        String value = val;
        doublefmt.setMaximumFractionDigits(dec);
        doublefmt.setMinimumFractionDigits(dec);
        doublefmt.setGroupingSize(0);
        value = JqLib.strExclude(value, ',');
        value = doublefmt.format(Double.parseDouble(value));
        length = value.length();
        dataHTML.append("<table width=\"100%\" border=\"0\" align=\"center\" cellspacing=\"1\" bgcolor=\"#E0E0E0\">\n");
        dataHTML.append("<tr>\n");
        if (dec == 0) {
            int flagNumber;
            if (length < (flagNumber = pre)) {
                for (int i = 0; i < pre - length - 1; ++i) {
                    if (this.isFlagNumber(flagNumber, false)) {
                        dataHTML.append("<td width=\"" + percent + "%\" align=\"center\"" + " bgcolor=\"#FFFFFF\" style=\"BORDER-RIGHT: black 1px solid;\"></td>\n");
                    }
                    else {
                        dataHTML.append("<td width=\"" + percent + "%\" align=\"center\" bgcolor=\"#FFFFFF\"></td>\n");
                    }
                    --flagNumber;
                }
                if (this.isFlagNumber(flagNumber, false)) {
                    dataHTML.append("<td width=\"" + percent + "%\" align=\"center\" " + "bgcolor=\"#FFFFFF\" style=\"BORDER-RIGHT: black 1px solid;\">" + mSigh + "</td>\n");
                }
                else {
                    dataHTML.append("<td width=\"" + percent + "%\" align=\"center\" bgcolor=\"#FFFFFF\">" + mSigh + "</td>\n");
                }
                --flagNumber;
                for (int i = 0; i < length; ++i) {
                    if (this.isFlagNumber(flagNumber, false)) {
                        dataHTML.append("<td width=\"" + percent + "%\" align=\"center\" " + "bgcolor=\"#FFFFFF\" style=\"BORDER-RIGHT: black 1px solid;\">" + this.formatNumber(value.charAt(i), ty) + "</td>\n");
                    }
                    else {
                        dataHTML.append("<td width=\"" + percent + "%\" align=\"center\" bgcolor=\"#FFFFFF\" >" + this.formatNumber(value.charAt(i), ty) + "</td>\n");
                    }
                    --flagNumber;
                }
            }
            else {
                for (int i = 0; i < pre; ++i) {
                    if (this.isFlagNumber(flagNumber, false)) {
                        dataHTML.append("<td width=\"" + percent + "%\" align=\"center\" " + "bgcolor=\"#FFFFFF\" style=\"BORDER-RIGHT: black 1px solid;\">" + this.formatNumber(value.charAt(length - pre + i), ty) + "</td>\n");
                    }
                    else {
                        dataHTML.append("<td width=\"" + percent + "%\" align=\"center\" bgcolor=\"#FFFFFF\" >" + this.formatNumber(value.charAt(length - pre + i), ty) + "</td>\n");
                    }
                    --flagNumber;
                }
            }
        }
        else {
            int flagNumber = pre - 2;
            if (length - 1 < pre) {
                for (int i = 0; i < pre - length; ++i) {
                    if (this.isFlagNumber(flagNumber, true)) {
                        dataHTML.append("<td width=\"" + percent + "%\" align=\"center\" " + "bgcolor=\"#FFFFFF\" style=\"BORDER-RIGHT: black 1px solid;\"></td>\n");
                    }
                    else {
                        dataHTML.append("<td width=\"" + percent + "%\" align=\"center\" bgcolor=\"#FFFFFF\"></td>\n");
                    }
                    --flagNumber;
                }
                if (this.isFlagNumber(flagNumber, true)) {
                    dataHTML.append("<td width=\"" + percent + "%\" align=\"center\" " + "bgcolor=\"#FFFFFF\" style=\"BORDER-RIGHT: black 1px solid;\">" + mSigh + "</td>\n");
                }
                else {
                    dataHTML.append("<td width=\"" + percent + "%\" align=\"center\" bgcolor=\"#FFFFFF\">" + mSigh + "</td>\n");
                }
                --flagNumber;
                for (int i = 0; i < length - 3; ++i) {
                    if (this.isFlagNumber(flagNumber, true)) {
                        dataHTML.append("<td width=\"" + percent + "%\" align=\"center\" " + "bgcolor=\"#FFFFFF\" style=\"BORDER-RIGHT: black 1px solid;\">" + this.formatNumber(value.charAt(i), ty) + "</td>\n");
                    }
                    else {
                        dataHTML.append("<td width=\"" + percent + "%\" align=\"center\" bgcolor=\"#FFFFFF\" >" + this.formatNumber(value.charAt(i), ty) + "</td>\n");
                    }
                    --flagNumber;
                }
            }
            else {
                for (int i = 0; i < pre - 2; ++i) {
                    if (this.isFlagNumber(flagNumber, true)) {
                        dataHTML.append("<td width=\"" + percent + "%\" align=\"center\" " + "bgcolor=\"#FFFFFF\" style=\"BORDER-RIGHT: black 1px solid;\">" + this.formatNumber(value.charAt(length - 1 - pre + i), ty) + "</td>\n");
                    }
                    else {
                        dataHTML.append("<td width=\"" + percent + "%\" align=\"center\" bgcolor=\"#FFFFFF\" >" + this.formatNumber(value.charAt(length - 1 - pre + i), ty) + "</td>\n");
                    }
                    --flagNumber;
                }
            }
            dataHTML.append("<td width=\"" + percent + "%\" align=\"center\" bgcolor=" + "\"#FFFFFF\" style=\"BORDER-LEFT: black 1px solid;\">" + this.formatNumber(value.charAt(length - 2), ty) + "</td>\n");
            dataHTML.append("<td width=\"" + percent + "%\" align=\"center\" bgcolor=\"#FFFFFF\" >" + this.formatNumber(value.charAt(length - 1), ty) + "</td>\n");
        }
        dataHTML.append("</tr>\n");
        dataHTML.append("</table>\n");
        return dataHTML.toString();
    }
    
    private String getTitleHTML(final int dec, final int pre) {
        final StringBuffer titleHTML = new StringBuffer();
        int i = pre - dec;
        double percent = 100.0 / pre;
        final int b = (int)Math.round(percent * 100.0);
        percent = b / 100.0;
        titleHTML.append("<table width=\"100%\" border=\"0\" align=\"center\" cellspacing=\"1\" bgcolor=\"#E0E0E0\">\n");
        titleHTML.append("<tr>\n");
        while (i >= 1) {
            switch (i) {
                case 9: {
                    titleHTML.append("<td width=\"" + percent + "%\" align=\"center\" bgcolor=\"#FFFFFF\">亿</td>\n");
                    break;
                }
                case 5:
                case 13: {
                    if (i == 13) {
                        titleHTML.append("<td width=\"" + percent + "%\" align=\"center\" bgcolor=\"#FFFFFF\"" + " style=\"BORDER-RIGHT: black 1px solid;\">万</td>\n");
                        break;
                    }
                    titleHTML.append("<td width=\"" + percent + "%\" align=\"center\" bgcolor=\"#FFFFFF\">万</td>\n");
                    break;
                }
                case 4:
                case 8:
                case 12: {
                    if (i == 4) {
                        titleHTML.append("<td width=\"" + percent + "%\" align=\"center\" bgcolor=\"#FFFFFF\" " + "style=\"BORDER-RIGHT: black 1px solid;\">千</td>\n");
                        break;
                    }
                    titleHTML.append("<td width=\"" + percent + "%\" align=\"center\" bgcolor=\"#FFFFFF\">千</td>\n");
                    break;
                }
                case 3:
                case 7:
                case 11: {
                    if (i == 7) {
                        titleHTML.append("<td width=\"" + percent + "%\" align=\"center\" bgcolor=\"#FFFFFF\" " + "style=\"BORDER-RIGHT: black 1px solid;\">百</td>\n");
                        break;
                    }
                    titleHTML.append("<td width=\"" + percent + "%\" align=\"center\" bgcolor=\"#FFFFFF\">百</td>\n");
                    break;
                }
                case 2:
                case 6:
                case 10: {
                    if (i == 10) {
                        titleHTML.append("<td width=\"" + percent + "%\" align=\"center\" bgcolor=\"#FFFFFF\" " + "style=\"BORDER-RIGHT: black 1px solid;\">十</td>\n");
                        break;
                    }
                    titleHTML.append("<td width=\"" + percent + "%\" align=\"center\" bgcolor=\"#FFFFFF\">十</td>\n");
                    break;
                }
                case 1: {
                    if (dec == 2) {
                        titleHTML.append("<td width=\"" + percent + "%\" align=\"center\" bgcolor=\"#FFFFFF\" " + "style=\"BORDER-RIGHT: black 1px solid;\">元</td>\n");
                        break;
                    }
                    titleHTML.append("<td width=\"" + percent + "%\" align=\"center\" bgcolor=\"#FFFFFF\" >元</td>\n");
                    break;
                }
            }
            --i;
        }
        if (dec == 2) {
            titleHTML.append("<td width=\"" + percent + "%\" align=\"center\" bgcolor=\"#FFFFFF\" style=" + "\"BORDER-LEFT: black 1px solid;\">角</td>\n");
            titleHTML.append("<td width=\"" + percent + "%\" align=\"center\" bgcolor=\"#FFFFFF\">分</td>\n");
        }
        titleHTML.append("</tr>\n");
        titleHTML.append("</table>\n");
        return titleHTML.toString();
    }
}
